@@ -1,10 +1,11 @@
-__version__ = '0.12.0'
+__version__ = '1.1.0'
 
 import logging
-from logging import NullHandler
 
-# Add NullHandler to prevent logging warnings
-logging.getLogger(__name__).addHandler(NullHandler())
+# Add NullHandler before importing Pika modules to prevent logging warnings
+logging.getLogger(__name__).addHandler(logging.NullHandler())
+
+# pylint: disable=C0413
 
 from pika.connection import ConnectionParameters
 from pika.connection import URLParameters
@@ -15,5 +16,5 @@ from pika.spec import BasicProperties
 from pika.adapters import BaseConnection
 from pika.adapters import BlockingConnection
 from pika.adapters import SelectConnection
-from pika.adapters import TornadoConnection
-from pika.adapters import TwistedConnection
+
+from pika.adapters.utils.connection_workflow import AMQPConnectionWorkflow
